@@ -1,9 +1,10 @@
 /*
- * Copyright (C) 2004-2006 Jean-Yves Lefort <jylefort@brutele.be>
+ * Link Monitor Applet
+ * Copyright (C) 2004-2008 Jean-Yves Lefort <jylefort@brutele.be>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -11,9 +12,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _LM_ICMP_H
@@ -25,27 +26,23 @@
 #include <netdb.h>
 #include <glib.h>
 #include "lm-shell.h"
+#include "lm-util.h"
 
 typedef struct
 {
-  uint8_t	icmp_type;
-  uint8_t	icmp_code;
-  uint16_t	host_id;
-  uint16_t	seq;
-  GTimeVal	sent;
-  GTimeVal	received;
+  const char	*error;		/* NULL if it's an echo reply */
+  uint8_t	host_id;
+  uint8_t	seq;
+  LMTimeSpan	received_time;
 } LMICMPReply;
 
 gboolean lm_icmp_send_echo_request (const LMSocket *sock,
 				    const struct addrinfo *addrinfo,
-				    uint16_t host_id,
-				    uint16_t seq,
+				    uint8_t host_id,
+				    uint8_t seq,
 				    GError **err);
 
 gboolean lm_icmp_reply_get (const LMSocket *sock, LMICMPReply *reply);
 
-gboolean lm_icmp_reply_is_echo_reply (const LMICMPReply *reply, int domain);
-double lm_icmp_reply_get_roundtrip_time (const LMICMPReply *reply);
-const char *lm_icmp_reply_get_description (const LMICMPReply *reply, int domain);
 
 #endif /* _LM_ICMP_H */
