@@ -1,9 +1,10 @@
 /*
- * Copyright (C) 2004-2006 Jean-Yves Lefort <jylefort@brutele.be>
+ * Link Monitor Applet
+ * Copyright (C) 2004-2008 Jean-Yves Lefort <jylefort@brutele.be>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -11,45 +12,24 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "config.h"
 #include <string.h>
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
+#include <glib/gi18n.h>
 #include <gnome.h>
 #include "lm-applet.h"
 #include "lm-shell.h"
-#include "lm-stock.h"
 #include "lm-util.h"
 
-/*** functions ***************************************************************/
-
-static GSList *lm_main_sockets_new (void);
-static LMSocket *lm_main_socket_new (int domain, int protocol);
-
-/*** implementation **********************************************************/
-
-static GSList *
-lm_main_sockets_new (void)
-{
-  GSList *sockets = NULL;
-
-  sockets = g_slist_append(sockets, lm_main_socket_new(AF_INET, IPPROTO_ICMP));
-#if WITH_IPV6
-  sockets = g_slist_append(sockets, lm_main_socket_new(AF_INET6, IPPROTO_ICMPV6));
-#endif
-
-  return sockets;
-}
-
 static LMSocket *
-lm_main_socket_new (int domain, int protocol)
+create_socket (int domain, int protocol)
 {
   LMSocket *sock;
 
@@ -63,6 +43,19 @@ lm_main_socket_new (int domain, int protocol)
   return sock;
 }
 
+static GSList *
+create_sockets (void)
+{
+  GSList *sockets = NULL;
+
+  sockets = g_slist_append(sockets, create_socket(AF_INET, IPPROTO_ICMP));
+#if WITH_IPV6
+  sockets = g_slist_append(sockets, create_socket(AF_INET6, IPPROTO_ICMPV6));
+#endif
+
+  return sockets;
+}
+
 int
 main (int argc, char **argv)
 {
@@ -70,12 +63,12 @@ main (int argc, char **argv)
   GdkPixbuf *icon;
 
   /* create sockets as root */
-  sockets = lm_main_sockets_new();
+  sockets = create_sockets();
 
   /* we don't need root privileges anymore */
   setuid(getuid());
 
-  g_log_set_fatal_mask(G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL);
+  g_log_set_fatal_mask(NULL, G_LOG_LEVEL_CRITICAL);
 
 #ifdef ENABLE_NLS
   bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
@@ -92,7 +85,7 @@ main (int argc, char **argv)
      * We can't use lm_error_dialog() because gtk_init() has not been
      * called yet.
      */
-    g_critical(_("multi-threading is not available"));
+    g_critical("multi-threading is not available");
   gdk_threads_init();
 
   gnome_program_init(PACKAGE,
@@ -106,14 +99,9 @@ main (int argc, char **argv)
 		     GNOME_PROGRAM_STANDARD_PROPERTIES,
 		     NULL);
 
-  lm_stock_init();
-
   icon = lm_pixbuf_new(GNOMEPIXMAPSDIR G_DIR_SEPARATOR_S "link-monitor-applet.png");
-  if (icon)
-    {
-      gtk_window_set_default_icon(icon);
-      g_object_unref(icon);
-    }
+  gtk_window_set_default_icon(icon);
+  g_object_unref(icon);
 
   lm_shell_new(sockets);
 
